#include <cassert>
#include <iterator>

class SymmetricMatrix {
	public:
		typedef unsigned int size_type;

		double operator() (const size_type i, const size_type j);
		double operator() (const size_type i, const size_type j) const;
		SymmetricMatrix operator+ (SymmetricMatrix M) const;
		SymmetricMatrix& operator= (const SymmetricMatrix& M);

		//set (*this) = (*this) + scale*B
		void add(const double& scale, const SymmetricMatrix& B);

		size_type cols() const;
		size_type rows() const;
	
		SymmetricMatrix(size_type size);
		~SymmetricMatrix();
		SymmetricMatrix(const SymmetricMatrix& M);

		/*
		class Iterator { 
			private:
				double* m_element;
				size_type m_row;
				size_type m_col;
			public:
				Iterator();
				bool operator!=(const Iterator& x) const;
				bool operator==(const Iterator& x) const;
				Iterator operator++(); // prefix
				Iterator operator++(int); // postfix
				double& operator*() const;
				double* operator->() const;
				friend class SymmetricMatrix;
		};
		Iterator begin() const;
		Iterator end() const;
		*/

	private:
		size_type m_size;
		double* m_data;
};

//--------------------------------------------------

void
SymmetricMatrix::add(const double& scale, const SymmetricMatrix& B) {
	SymmetricMatrix& A = *this;

	//check dimensions:
	assert(A.m_size == B.m_size);

	for (size_type i=0; i < A.m_size; ++i) {
		for(size_type j=0; j<i+1; ++j) {
			A(i,j) = A(i,j) + scale*B(i,j);
		}
	}
}
