#include "Matrix.hpp"
#include "SymmetricMatrix.hpp"
#include <chrono>
#include <iostream>

template<typename MATRIX>
void fill(MATRIX& mat) {
	typedef typename MATRIX::size_type size_type;

	for (size_type i = 0; i < mat.rows(); ++i) {
		for (size_type j = 0; j < mat.cols(); ++j) {
			mat(i,j) = i*mat.rows()+j;	
		}
	}
}

int main() {
	using std::chrono::system_clock;

	//size:
	unsigned int size = 2000;

	//fill matrices:
	Matrix mat(size,size);
	SymmetricMatrix smat(size);
	fill(mat);
	fill(smat);

	system_clock::time_point now = system_clock::now();	
	Matrix mat2 = mat+mat;
	system_clock::duration tmat = system_clock::now()-now;

	now = system_clock::now();
	SymmetricMatrix smat2 = smat+smat;
	system_clock::duration tsmat =  system_clock::now()-now;
	
	//convert clock readings to seconds
	double to_seconds = system_clock::period::num/double(system_clock::period::den);

	std::cout << "Matrix addition took:          " << tmat.count()*to_seconds << " s" << std::endl;
	std::cout << "SymmetricMatrix addition took: " << tsmat.count()*to_seconds << " s" << std::endl;
	return 0;
}
